seqtools.split_sequence_cyclically_by_weights_without_overhang
==============================================================

.. autofunction:: abjad.tools.seqtools.split_sequence_cyclically_by_weights_without_overhang
